####################################################################################
#       Copyright (c) 1998 Simis Holdings Limited. All Rights Reserved.
#
# PLEASE READ THIS COMMENT BEFORE ALTERING ANY DATA IN THIS FILE.
#
# This is the game data file for Team2. It contains game data of three forms:
#     1. Strings    - any arbitary character sequence
#     2. Integers   - positive or negative numeric sequences without a period "."
#     3. Floats     - floating point numeric sequences; must contain a period "."
#     4. Void       - nothing, empty sequence, defines the data id only
#
# The purpose of this file is to extract all language specific, and game's designer
# changeable, data to one place. This avoids the need to alter the code when
# tweaking performance or (hopefully) doing language conversions.
#
# Syntax:
#
# Comments
# --------
# Any line beginning with a hash "#" character is a comment and is ignored.
# Comments can only exist as the first none whitespace character of a line.
#
# IDs
# ---
# All data entered in the file has an associated ID. The ID is how the data is
# referenced in code. The ID is a string followed by an equals sign "=" followed
# by the data it is to be associated with (e.g. mydata = Some string).
# The ID must be the none whitespace character on the line it is defined on.
# The ID itself must not contain whitespace.
#
# Data
# ----
# 1. Strings
#    Strings can be defined in two ways. Firstly, any data that does not start
# with a number is considered a string. This type of string is terminated by the
# end of the line. Secondly, an opening brace "{" character can be used to start
# the string; the string is not terminated until a close brace "}" character is
# encountered. This type of string can be split across multiple lines.
#
# 2. Integers
#    Integers are any number that does not contain a period "." character.
# Integers must only contain numeric digits (with the exception of the negative
# sign "-" as the first character) and are terminated by the end of the line.
#
# 3. Floats
#    Floats are any number that does contain a period "." character. Floats may
# be defined usign scientific notation (e.g. 1.3e24) if required.
#
# 4. Void
#    Void data is no data. If an ID is defined with nothing but whitespace after
# the equals sign then the ID is defined as void.
#
# Tokens
# ------
# Data can be further partitioned with tokens. Tokens are strings which are
# contained in square brackets: "[" and "]", e.g. [mytoken]. The default
# token (if none is defined) is [] (i.e. none). Tokens can be used as sections
# to split up ID data. Normally the system would generate a parse error if
# two indentical IDs were defined in the same file, but if they are defined
# under different tokens then the file will parse correctly.
#
# Notes:
# 1. The format of this file is similar to Windows INI files.
# 2. The maximum length of an ID is 10 characters.
# 3. Tokens can be up to 8 characters.
# 4. The maximum line length is 1024 characters.
# 5. Strings can be up to 4096 character when delimited.
# 6. Avoid using colons ":" in either token or ID definitions (they are used
# internally.
# 7. Tokens beginning with "!" will be available in the console system as
# variables in debug builds. *-x-left z*=front; h= hud
####################################################################################

[!Cpt]
XOffset = 0.80
YOffset = -0.62
ZOffset = 1.4
HXOffset = -1.12
HYOffset = 0.96
HZOffset = 0.0
XMin = -90.0
XMax = 110.0
YMin = -115.0
YMax = 85.0
ZoomXMin = -0.4
ZoomXMax = 0.2
ZoomYMin = -0.6
ZoomYMax = 0.2
ZoomZMin = -0.4
ZoomZMax = 2.6
MoveSpd = 45.0
ZoomSpd = 0.5

[!Hud]
FStat01  = OTB
FStat02  = NP
FStat03  = SAFE
FMode01  = MAN
FMode02  = AUTO
FBrst01  = LOW
FBrst02  = HIGH

[!MFD]
MFD00	 = THREATS
MFD01	 = NAVIGATION
MFD02    = RADAR
MFD03 	 = SHKVAL
MFD04 	 = WEAPON STATUS
MFD05 	 = ENGINES STATUS
MFD06 	 = SYSTEMS STATUS
MFD07 	 = MISSION STATUS
ARADNAME = AIR RADAR
GRADNAME = GROUND RADAR
M06Eng1  = Engine 1
M06Eng2  = Engine 2
M06RPM   = RPM
M06Fuel  = Fuel
M07LENG  = Left Engine
M07RENG  = Right Engine
M07NUC   = Nose Undercarriage
M07LUC   = Left Undercarriage
M07RUC   = Right Undercarriage
M07TURR  = Turret
M07GUN   = Gun
M07RAD   = Radar
M07FUEL  = Fuel System
M07TRANS = Transmission
M07HYD   = Hydraulics
M07NAV   = Navigation
M07ECM   = ECM RWR
M07PYL1  = Pylon 1
M07PYL2  = Pylon 2
M07PYL3  = Pylon 3
M07PYL4  = Pylon 4
M07PYL5  = Pylon 5
M07PYL6  = Pylon 6
M07LECM  = Left ECM
M07RECM  = Right ECM
M08STA01 = Active
M08STA02 = Failed
M08STA03 = Successful
M08SCO01 = Disaster
M08SCO02 = Failed
M08SCO03 = Success
M08SCO04 = Victory!
VOffset00 = -0.45
VOffset01 = -0.45
VOffset02 = -0.45
VOffset03 = -0.45

[!Inst]
CycXMin = -3.0
CycXMax = 3.0
CycZMin = -3.0
CycZMax = 3.0
WWZMax = 100.0